==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/item/FurSmithingUpgradeTemplate.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.Frostiful;
import java.util.List;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_8052;

public class FurSmithingUpgradeTemplate {


    /// Text ///
    private static final class_2561 FUR_UPGRADE_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "upgrade",
                    Frostiful.id("fur_upgrade")
            )
    ).method_27692(FSmithingTemplateItem.TITLE_FORMATTING);
    private static final class_2561 FUR_UPGRADE_APPLIES_TO_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.applies_to")
            )).method_27692(FSmithingTemplateItem.DESCRIPTION_FORMATTING);
    private static final class_2561 FUR_UPGRADE_INGREDIENTS_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.ingredients")
            )
    ).method_27692(FSmithingTemplateItem.DESCRIPTION_FORMATTING);
    private static final class_2561 FUR_UPGRADE_BASE_SLOT_DESCRIPTION_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item", Frostiful.id("smithing_template.fur_upgrade.base_slot_description")
            )
    );
    private static final class_2561 FUR_UPGRADE_ADDITIONS_SLOT_DESCRIPTION_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.additions_slot_description")
            )
    );

    private static final class_2960 EMPTY_SLOT_FUR_PADDING_TEXTURE = Frostiful.id("item/empty/fur_padding");


    public static class_8052 createItem() {
        return new class_8052(
                FUR_UPGRADE_APPLIES_TO_TEXT,
                FUR_UPGRADE_INGREDIENTS_TEXT,
                FUR_UPGRADE_TEXT,
                FUR_UPGRADE_BASE_SLOT_DESCRIPTION_TEXT,
                FUR_UPGRADE_ADDITIONS_SLOT_DESCRIPTION_TEXT,
                getFurUpgradeEmptyBaseSlotTextures(),
                getFurUpgradeEmptyAdditionsSlotTextures()
        );
    }

    private static List<class_2960> getFurUpgradeEmptyBaseSlotTextures() {
        return List.of(
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_HELMET_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_CHESTPLATE_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_LEGGINGS_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_BOOTS_TEXTURE
        );
    }

    private static List<class_2960> getFurUpgradeEmptyAdditionsSlotTextures() {
        return List.of(EMPTY_SLOT_FUR_PADDING_TEXTURE);
    }

    private FurSmithingUpgradeTemplate() {
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/item/FurSmithingUpgradeTemplate.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.Frostiful;
import java.util.List;
import net.minecraft.class_156;
import net.minecraft.class_1792;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_8052;

public class FurSmithingUpgradeTemplate {


    /// Text ///
    private static final class_2561 FUR_UPGRADE_APPLIES_TO_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.applies_to")
            )).method_27692(FSmithingTemplateItem.DESCRIPTION_FORMATTING);
    private static final class_2561 FUR_UPGRADE_INGREDIENTS_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.ingredients")
            )
    ).method_27692(FSmithingTemplateItem.DESCRIPTION_FORMATTING);
    private static final class_2561 FUR_UPGRADE_BASE_SLOT_DESCRIPTION_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item", Frostiful.id("smithing_template.fur_upgrade.base_slot_description")
            )
    );
    private static final class_2561 FUR_UPGRADE_ADDITIONS_SLOT_DESCRIPTION_TEXT = class_2561.method_43471(
            class_156.method_646(
                    "item",
                    Frostiful.id("smithing_template.fur_upgrade.additions_slot_description")
            )
    );

    private static final class_2960 EMPTY_SLOT_FUR_PADDING_TEXTURE = Frostiful.id("item/empty/fur_padding");


    public static class_8052 createItem(class_1792.class_1793 settings) {
        return new class_8052(
                FUR_UPGRADE_APPLIES_TO_TEXT,
                FUR_UPGRADE_INGREDIENTS_TEXT,
                FUR_UPGRADE_BASE_SLOT_DESCRIPTION_TEXT,
                FUR_UPGRADE_ADDITIONS_SLOT_DESCRIPTION_TEXT,
                getFurUpgradeEmptyBaseSlotTextures(),
                getFurUpgradeEmptyAdditionsSlotTextures(),
                settings
        );
    }

    private static List<class_2960> getFurUpgradeEmptyBaseSlotTextures() {
        return List.of(
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_HELMET_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_CHESTPLATE_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_LEGGINGS_TEXTURE,
                FSmithingTemplateItem.EMPTY_ARMOR_SLOT_BOOTS_TEXTURE
        );
    }

    private static List<class_2960> getFurUpgradeEmptyAdditionsSlotTextures() {
        return List.of(EMPTY_SLOT_FUR_PADDING_TEXTURE);
    }

    private FurSmithingUpgradeTemplate() {
    }
}
